
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 111
#define YY_END_OF_BUFFER 112
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[510] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  112,  110,   24,  104,  103,   23,
       25,   74,  106,  110,   23,   22,   20,   25,   31,   20,
      110,   25,  110,  110,  110,  110,  110,  110,   24,  103,
       25,   74,  106,  110,   22,   31,   28,  111,   28,   28,
       34,  111,  111,  111,   70,   70,   55,   70,   70,   57,
       59,   70,   70,   64,   70,   70,   70,   70,   70,   70,
       70,   70,   70,   70,   70,   70,   70,   67,   67,   67,

       67,   93,   93,  102,  102,   36,   32,   35,   33,   41,
       40,   39,   41,   84,   79,   84,   83,   54,   84,   84,
       56,   58,   84,   84,   75,   84,   84,   84,   84,   84,
       84,   84,   84,   84,   84,   84,   84,   78,   78,   78,
       78,   90,   90,   99,   99,   87,   87,   96,   96,  107,
      109,  108,  111,  111,  111,  111,  111,   71,   43,    0,
      105,    0,   22,   22,   22,   22,    0,    0,    0,   72,
        0,   20,   29,    0,    0,    0,    0,   25,   23,   20,
       94,   85,   19,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    2,    0,   43,    1,   22,   22,

        0,    0,    0,   34,    0,    0,    0,    0,    0,   69,
        0,   59,    0,   59,   59,   59,    0,   47,   49,    0,
        0,    0,   45,    0,    0,    0,    0,    0,    0,    0,
      100,   91,   63,    0,    0,    0,    0,    0,    0,    0,
        0,   69,    0,    0,    0,   92,  101,    0,    0,   37,
       37,    0,    0,    0,    0,    0,   80,    0,    0,   81,
       81,    0,    0,    0,    0,    0,   58,    0,   58,   58,
       58,    0,   46,   48,    0,    0,    0,   44,    0,    0,
        0,    0,    0,    0,    0,   97,   88,   62,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   89,

       98,   86,   95,  108,    0,    0,    0,    0,    0,    0,
        0,    0,   22,    0,   22,    0,    0,    0,    0,    0,
       17,    0,    0,    0,    0,    0,    0,    0,   20,    0,
        0,    4,   18,   19,   19,   19,   19,   19,   19,   19,
       42,    0,    5,    0,    0,    0,    0,   51,   59,    0,
       59,    0,   53,    6,   51,   63,   68,    0,    0,    7,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    8,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   50,   58,    0,   58,    0,   52,    9,
       50,   62,    0,    0,   10,   11,  108,    0,   14,    0,

        0,    0,    0,   16,    0,   73,    0,   15,   30,   15,
        0,    0,    0,    0,    0,    0,    0,    0,   16,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   26,    0,    0,    0,   27,    0,    0,
        0,    0,   66,   65,    0,   38,    0,    0,    0,    0,
       82,    0,    0,    0,    0,   76,   77,    0,    0,   13,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       13,    0,    3,   12,    3,    0,    0,    0,    0,    0,

       21,    0,    0,    0,   61,   60,    0,    0,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    6,    7,    8,    9,   10,    6,    1,
        1,   11,   12,   13,   14,   15,   16,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,    6,    6,   18,
       19,   20,    6,   10,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
        1,   22,    1,    1,   10,   23,   24,   25,   26,   27,

       28,   21,   29,   30,   31,   21,   21,   32,   33,   34,
       35,   36,   21,   37,   38,   39,   40,   21,   21,   41,
       21,   21,   42,   43,   44,   45,    1,   46,   47,   48,
       49,   49,   49,   49,   50,   51,   52,   53,   54,   55,
       56,   57,   58,   59,   60,   49,   61,   62,   63,   49,
       49,   64,   65,   66,   67,   68,   69,   49,   70,   49,
       49,   71,   49,   72,   73,   74,   49,   49,   49,   71,
       71,   75,   75,   75,   75,   75,   76,   76,   76,   76,
       76,   76,   77,   76,   76,   78,   78,   79,   78,   78,
       78,    1,    1,   80,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,   81,   81,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   82,   83,   84,   84,   84,
       84,   84,   84,   84,   84,   84,   84,   84,   85,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[86] =
    {   0,
        1,    2,    2,    2,    2,    1,    1,    2,    1,    1,
        2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        3,    1,    2,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    1,    4,    1,    1,    5,    5,    6,    5,    5,
        5,    5,    6,    6,    6,    6,    6,    6,    6,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        6,    5,    5,    5,    7,    8,    8,    8,    9,    1,
        4,   10,   10,   10,   10
    } ;

static const flex_int16_t yy_base[563] =
    {   0,
        0,   84,   84,   85,   87,   90,  165,  248,  102,  106,
       91,   97,   94,  101, 1205, 1203, 1202, 1201,  113,  117,
      331,  414,  108,  118,  103,  109,  110,  119,  120,  121,
      123,  136,  497,    0, 1223, 1756, 1756, 1756, 1756, 1756,
     1756,  144, 1211,  141, 1204,  142,  209,  163, 1756,  219,
      120,  232,  318, 1143,  115, 1173,    0, 1139,  214,  271,
      127,  357,  158,  224,  280, 1194, 1756, 1756, 1170, 1192,
     1756,  297, 1183, 1179, 1756, 1204, 1756,  157,  237, 1756,
      290, 1190, 1183, 1756,  140, 1170,  167,  275,  178, 1169,
      196, 1104,  298, 1130,    0, 1091, 1159, 1756, 1133, 1131,

     1099, 1756, 1100, 1756, 1098, 1756, 1756, 1756, 1756, 1756,
     1756,  581, 1094, 1756, 1756, 1131,  665, 1756,  252,  262,
     1756,  339, 1119, 1118, 1756,  180, 1107,  337,  350,  230,
     1109,  269, 1053,  342, 1079,    0, 1041, 1756, 1084, 1083,
     1068, 1756, 1068, 1756, 1067, 1756, 1066, 1756, 1064, 1756,
     1756, 1756, 1025,  314, 1055,    0, 1021, 1756, 1756, 1087,
     1756, 1079,  363,  216,  310,  367,  323,  375, 1092, 1756,
     1072,  379, 1756,   72, 1036,    0,    0, 1756, 1756, 1054,
     1756, 1756,  394,  405,    0,  704,    0,    0,    0,  425,
      437, 1074,  281, 1074, 1756,  250, 1073, 1756,  407,  473,

     1049, 1017, 1039, 1756,  475, 1028, 1024, 1028,  353, 1756,
     1038,  489, 1038,  380,  390,  490,  469, 1756, 1756,  233,
     1026, 1021, 1756, 1018, 1004, 1010, 1011, 1010,  999,  987,
     1756, 1756, 1756,  458,  240,    0,  721,    0,    0,    0,
      484, 1014,  969,  967,  946, 1756, 1756,  513,  983,    0,
     1756,  331,  945,    0,    0,  914, 1756,  592,  951,    0,
     1756,  359,  914,    0,    0,  938,  572,  934,  416,  493,
      573,  497, 1756, 1756,  446,  922,  920, 1756,  917,  904,
      908,  914,  914,  901,  899, 1756, 1756, 1756,  728,  443,
        0,  756,    0,    0,    0,  770,  895,  894,  872, 1756,

     1756, 1756, 1756, 1756,  770,    0,  798,    0,    0,    0,
      812,  551,  517,  906,  898,  890,  823,  851,  848,  814,
     1756,  868,  877,    0,  837,    0,    0,    0,  867,  946,
      866, 1756,  881,  783,  905,  916,  920,  954, 1030, 1038,
     1756,  878, 1756,  872,  843,  832,  807, 1756,  606,  826,
      825,  828, 1756, 1756, 1756, 1756, 1756,  806,  803, 1756,
      818,  751,  780,  777,  741, 1122,    0,  755,    0,    0,
        0, 1756,  784,  714,  740,  724,  686, 1206,    0,  703,
        0,    0,    0, 1756,  608,  728,  723,  723, 1756, 1756,
     1756, 1756,  697,  695, 1756, 1756, 1756,  555, 1756,  834,

     1245,  999,  909, 1756,  692, 1756,  702,    0, 1756, 1756,
      630,  606,  633,    0,  594,  676,  854,  660, 1756,  622,
      582,  610,  560,  583,  547,  558,  520,  551,  515,  545,
      505,  526,  489, 1756,  916,  521,  508, 1756,  494,  506,
      491,  486, 1756, 1756,  638, 1756,  999, 1262, 1023,  881,
     1756, 1023, 1279, 1052,  466, 1756, 1756,  462,  460, 1756,
     1067,    0, 1296,    0,    0,    0, 1310,  457, 1367,  481,
     1319,  490, 1326,  635, 1332,  640, 1039,  662, 1348,  751,
     1350,  753, 1357,  421,  439,  408,  417,  400,  396,  377,
     1756, 1095, 1756, 1756, 1756,  356,  353,  335,  328,  325,

     1756,  280,  265,  250, 1756, 1756,  173,  163, 1756, 1427,
     1437, 1447, 1457, 1467, 1477, 1487, 1497, 1507, 1517, 1527,
     1537, 1547, 1557, 1567, 1576, 1582, 1587, 1592, 1601, 1607,
     1612, 1617, 1622, 1627, 1632, 1637, 1642, 1647, 1652, 1657,
     1662, 1664, 1669,  157, 1674, 1679, 1684,  134, 1686, 1691,
     1696, 1698, 1703, 1708, 1716, 1721, 1726,  122, 1731, 1736,
     1741, 1746
    } ;

static const flex_int16_t yy_def[563] =
    {   0,
      509,    1,  510,  510,  511,  511,  512,  512,  513,  513,
      514,  514,  515,  515,  516,  516,  517,  517,  518,  518,
      519,  519,  520,  520,  521,  521,  522,  522,  523,  523,
      524,  524,  511,   33,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  525,  509,  509,  525,
      509,  509,  509,  509,  509,  526,  527,  528,  509,  509,
      529,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  530,  531,  532,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  533,  534,  535,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  536,  537,  538,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,   50,  509,  509,  539,  540,  541,  509,  509,  172,
      509,  509,  509,  509,  542,  509,  542,  542,  542,  509,
      509,  509,  509,  529,  509,  529,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  543,  509,  543,  543,  543,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  544,
      509,  509,  545,  546,  547,  509,  509,  509,  509,  548,
      509,  509,  549,  550,  551,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      552,  509,  552,  552,  552,  509,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  553,  509,  553,  553,  553,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  554,  509,  554,  554,  554,  172,  509,
      509,  509,  555,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  556,  509,  556,  556,
      556,  509,  509,  509,  509,  509,  509,  509,  557,  509,
      557,  557,  557,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  558,  509,  509,
      509,  509,  559,  560,  561,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  330,  509,
      509,  562,  509,  562,  562,  562,  509,  509,  555,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  509,    0,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509
    } ;

static const flex_int16_t yy_nxt[1842] =
    {   0,
       36,   37,   38,   36,   39,   40,   41,   42,   36,   41,
       43,   44,   40,   44,   45,   41,   46,   41,   41,   41,
       47,   48,   49,   47,   47,   47,   50,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   51,   52,   36,   36,   53,   53,   36,   53,   53,
       53,   53,   36,   36,   36,   36,   36,   36,   36,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       36,   53,   53,   53,   36,   53,   53,   53,   53,   54,
       53,   55,   56,   57,   58,   59,   68,   68,   60,   71,
       61,   62,   71,   68,   63,   64,   68,   64,   72,   68,

       65,   72,  105,   68,   68,   68,   66,   70,   68,  105,
       68,   68,   68,   73,   74,  111,   73,   74,  145,  111,
       68,   68,   68,   68,  408,   68,   99,  145,  181,  195,
       99,  149,  139,  196,  103,  112,  260,  100,   68,  112,
      103,  100,  139,  140,  149,  158,  143,  158,  158,  324,
      324,  159,  143,  140,  160,  162,  165,  163,  166,  250,
      184,  182,  198,  147,  147,   69,   69,   68,  161,  167,
      178,  211,   76,  212,  220,   77,   78,  221,   78,   79,
       80,   81,   82,  101,   83,  179,   84,  101,  435,  141,
       85,   86,  185,  185,  113,  223,   87,   88,  113,  141,

      223,  224,   89,   90,  231,  228,   91,  178,  229,  435,
      168,  169,  168,  168,  275,  191,  170,  276,  191,  171,
      168,  169,  168,  168,  192,  192,  170,  192,  198,  171,
      193,  173,  164,  168,  169,  168,  168,  232,  162,  170,
      163,  173,  171,  167,   92,  180,   93,   94,   95,   96,
       68,  213,  195,  214,  173,   97,  196,  283,   77,   78,
      284,   78,   79,   80,   81,   82,  266,   83,  267,   84,
      223,  223,  191,   85,   86,  191,  268,  286,  269,   87,
       88,  192,  192,  508,  192,   89,   90,  193,  507,   91,
      174,  175,  176,  177,  199,  192,  200,  193,  225,  204,

      174,  175,  176,  177,  215,  226,  216,  167,  205,  227,
      287,  218,  219,  174,  175,  176,  177,  217,  435,  168,
      169,  168,  168,  206,  207,  170,  313,   92,  171,   93,
       94,   95,   96,  115,  314,  116,  314,  167,  117,  315,
      173,  118,  119,  234,  119,  120,  121,  122,  123,  235,
      124,  506,  125,  270,  505,  271,  126,  127,  158,  305,
      158,  158,  128,  129,  197,  278,  272,  160,  130,  131,
      278,  279,  132,  280,  504,  236,  236,  165,  346,  166,
      281,  165,  503,  166,  282,  316,  502,  289,  347,  323,
      167,  306,  306,  290,  167,  330,  214,  330,  330,  174,

      175,  176,  177,  501,  331,  172,  349,  217,  367,  367,
      133,  198,  134,  135,  136,  137,  115,  217,  116,  291,
      291,  117,  500,  313,  118,  119,  499,  119,  120,  121,
      122,  123,  269,  124,  167,  125,  379,  379,  191,  126,
      127,  191,  205,  272,  205,  128,  129,  192,  192,  496,
      192,  130,  131,  193,  317,  132,  318,  319,  332,  320,
      509,  509,  509,  509,  497,  183,  183,  492,  183,  183,
      509,  336,  183,  183,  498,  183,  183,  204,  183,  337,
      350,  183,  350,  278,  278,  351,  205,  199,  490,  200,
      338,  339,  489,  133,  340,  134,  135,  136,  137,  150,

      167,  206,  207,  215,  215,  216,  216,  151,  386,  385,
      386,  354,  488,  387,  273,  274,  217,  217,  233,  233,
      272,  233,  233,  361,  487,  233,  233,  493,  493,  486,
      233,  355,  205,  313,  233,  233,  493,  493,  233,  152,
      233,  485,  152,  152,  167,  152,  152,  152,  152,  233,
      233,  484,  158,  233,  158,  158,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  483,  152,  152,
      152,  482,  152,  152,  152,  152,  153,  152,  154,  155,
      156,  157,  248,  481,  248,  248,  270,  270,  271,  271,
      480,  249,  362,  479,  363,  364,  478,  365,  477,  272,

      272,  250,  373,  476,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  349,  251,  385,  475,  251,  251,  474,  251,
      251,  251,  251,  217,  317,  272,  318,  319,  473,  320,
      251,  251,  251,  251,  251,  251,  251,  251,  251,  251,
      251,  461,  251,  251,  251,  472,  251,  251,  251,  251,
      471,  251,  252,  253,  254,  255,  258,  470,  258,  258,
      469,  374,  467,  375,  376,  259,  377,  330,  463,  330,
      330,  493,  493,  462,  462,  260,  493,  493,  260,  260,
      260,  260,  260,  260,  260,  260,  260,  260,  260,  260,

      260,  260,  260,  260,  260,  260,  460,  261,  493,  493,
      261,  261,  459,  261,  261,  261,  261,  362,  458,  363,
      364,  457,  365,  456,  261,  261,  261,  261,  261,  261,
      261,  261,  261,  261,  261,  455,  261,  261,  261,  387,
      261,  261,  261,  261,  387,  261,  262,  263,  264,  265,
      334,  335,  261,  333,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  454,  183,  183,  233,  233,  453,
      356,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  390,  233,  233,  330,  452,  330,  330,  288,  288,
      451,  288,  288,  331,  450,  288,  288,  493,  493,  493,

      493,  391,  288,  288,  251,  392,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  449,
      288,  288,  448,  396,  288,  447,  288,  446,  445,  444,
      304,  304,  443,  304,  304,  288,  288,  304,  304,  288,
      442,  351,  351,  304,  304,  304,  441,  397,  304,  304,
      304,  304,  304,  304,  304,  304,  304,  304,  304,  304,
      304,  440,  304,  304,  468,  420,  304,  421,  304,  168,
      169,  168,  168,  439,  438,  170,  416,  304,  304,  405,
      434,  304,  417,  169,  417,  417,  404,  403,  170,  435,
      173,  418,  402,  401,  399,  399,  400,  399,  399,  399,

      398,  399,  399,  173,  436,  437,  330,  399,  330,  330,
      168,  169,  168,  168,  315,  331,  170,  330,  434,  330,
      330,  330,  315,  330,  330,  395,  331,  435,  394,  393,
      331,  173,  278,  411,  278,  412,  413,  414,  415,  278,
      389,  278,  436,  437,  278,  278,  388,  278,  384,  174,
      175,  176,  177,  406,  269,  330,  407,  330,  330,  380,
      374,  378,  375,  376,  331,  377,  408,  372,  409,  408,
      408,  408,  408,  408,  408,  408,  408,  408,  408,  408,
      408,  408,  408,  408,  408,  408,  408,  422,  410,  423,
      368,  410,  410,  366,  410,  410,  410,  410,  424,  360,

      425,  359,  426,  358,  427,  410,  410,  410,  410,  410,
      410,  410,  410,  410,  410,  410,  357,  410,  410,  410,
      223,  410,  410,  410,  410,  411,  410,  412,  413,  414,
      415,  330,  223,  330,  330,  223,  428,  353,  429,  330,
      331,  330,  330,  223,  223,  399,  223,  352,  331,  399,
      399,  223,  348,  399,  214,  399,  345,  209,  208,  446,
      446,  344,  446,  446,  399,  399,  446,  446,  399,  446,
      343,  342,  446,  446,  446,  341,  195,  446,  198,  446,
      329,  325,  322,  451,  451,  495,  451,  451,  446,  446,
      451,  451,  446,  493,  321,  164,  451,  312,  451,  311,

      307,  304,  451,  451,  493,  493,  451,  303,  451,  302,
      301,  300,  430,  299,  431,  298,  297,  451,  451,  296,
      432,  451,  433,  248,  292,  248,  248,  460,  460,  288,
      460,  460,  285,  277,  460,  460,  274,  273,  257,  256,
      460,  247,  250,  246,  245,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  244,  251,  243,  242,  251,  251,  241,
      251,  251,  251,  251,  411,  237,  412,  413,  414,  415,
      233,  251,  251,  251,  251,  251,  251,  251,  251,  251,
      251,  251,  230,  251,  251,  251,  222,  251,  251,  251,

      251,  219,  251,  252,  253,  254,  255,  258,  218,  258,
      258,  210,  209,  208,  203,  202,  201,  190,  186,  183,
      164,  161,  509,  109,  109,  107,  260,  107,  509,  260,
      260,  260,  260,  260,  260,  260,  260,  260,  260,  260,
      260,  260,  260,  260,  260,  260,  260,  509,  261,  509,
      509,  261,  261,  509,  261,  261,  261,  261,  509,  509,
      509,  509,  509,  509,  509,  261,  261,  261,  261,  261,
      261,  261,  261,  261,  261,  261,  509,  261,  261,  261,
      509,  261,  261,  261,  261,  509,  261,  262,  263,  264,
      265,  399,  399,  509,  509,  399,  399,  399,  399,  399,

      399,  399,  399,  399,  399,  509,  399,  399,  446,  446,
      509,  509,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  509,  446,  446,  451,  451,  509,  509,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  509,
      451,  451,  460,  460,  509,  491,  460,  460,  460,  460,
      460,  460,  460,  460,  460,  460,  460,  460,  460,  509,
      460,  460,  509,  509,  460,  493,  460,  509,  417,  169,
      417,  417,  493,  493,  170,  460,  460,  509,  494,  460,
      493,  509,  509,  509,  493,  493,  493,  509,  493,  173,
      509,  493,  493,  509,  493,  493,  493,  493,  493,  509,

      509,  494,  493,  494,  493,  509,  509,  509,  509,  509,
      509,  493,  509,  493,  493,  493,  493,  493,  509,  493,
      509,  509,  493,  493,  509,  509,  494,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   75,   75,   75,
       75,   75,   75,   75,   75,   75,   75,   98,   98,   98,
       98,   98,   98,   98,   98,   98,   98,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  102,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  108,  108,  108,

      108,  108,  108,  108,  108,  108,  108,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  114,  114,  114,
      114,  114,  114,  114,  114,  114,  114,  138,  138,  138,
      138,  138,  138,  138,  138,  138,  138,  142,  142,  142,
      142,  142,  142,  142,  142,  142,  142,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  146,  146,  146,
      146,  146,  146,  146,  146,  146,  146,  148,  148,  148,
      148,  148,  148,  148,  148,  148,  148,  172,  172,  509,
      509,  509,  509,  509,  509,  172,  187,  187,  187,  187,
      187,  188,  188,  188,  188,  188,  189,  189,  509,  509,

      189,  194,  194,  194,  194,  194,  194,  194,  194,  194,
      194,  238,  238,  238,  238,  238,  239,  239,  239,  239,
      239,  240,  240,  509,  509,  240,  293,  293,  293,  293,
      293,  294,  294,  294,  294,  294,  295,  295,  509,  509,
      295,  308,  308,  308,  308,  308,  309,  309,  309,  309,
      309,  310,  310,  509,  509,  310,  326,  326,  326,  326,
      326,  327,  327,  327,  327,  327,  328,  328,  333,  333,
      333,  333,  333,  356,  356,  356,  356,  356,  369,  369,
      369,  369,  369,  370,  370,  370,  370,  370,  371,  371,
      381,  381,  381,  381,  381,  382,  382,  382,  382,  382,

      383,  383,  392,  392,  392,  392,  392,  397,  397,  397,
      397,  397,  404,  404,  404,  404,  404,  419,  419,  419,
      419,  509,  509,  419,  419,  251,  251,  251,  251,  251,
      261,  261,  261,  261,  261,  464,  464,  464,  464,  464,
      465,  465,  465,  465,  465,  466,  466,  509,  509,  466,
      491,  491,  491,  491,  491,   35,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509
    } ;

static const flex_int16_t yy_chk[1842] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    3,    4,    2,    5,
        2,    2,    6,   11,    2,    2,   13,    2,    5,   12,

        2,    6,   13,   14,    9,   25,    2,    4,   10,   14,
       23,   26,   27,    5,    5,   19,    6,    6,   27,   20,
       24,   28,   29,   30,  558,   31,    9,   28,   51,   61,
       10,   31,   23,   61,   11,   19,  548,    9,   32,   20,
       12,   10,   24,   23,   32,   42,   25,   42,   42,  174,
      174,   42,   26,   24,   42,   44,   46,   44,   46,  544,
       55,   51,   63,   29,   30,    3,    4,    7,   63,   46,
       48,   78,    7,   78,   85,    7,    7,   85,    7,    7,
        7,    7,    7,    9,    7,   48,    7,   10,  508,   23,
        7,    7,   55,   55,   19,   87,    7,    7,   20,   24,

       87,   87,    7,    7,   91,   89,    7,   48,   89,  507,
       47,   47,   47,   47,  126,   59,   47,  126,   59,   47,
       50,   50,   50,   50,   59,   59,   50,   59,   64,   50,
       59,   47,  164,   52,   52,   52,   52,   91,   64,   52,
       64,   50,   52,  164,    7,   50,    7,    7,    7,    7,
        8,   79,  196,   79,   52,    8,  196,  130,    8,    8,
      130,    8,    8,    8,    8,    8,  119,    8,  119,    8,
      220,  220,   60,    8,    8,   60,  120,  132,  120,    8,
        8,   60,   60,  504,   60,    8,    8,   60,  503,    8,
       47,   47,   47,   47,   65,  193,   65,  193,   88,   72,

       50,   50,   50,   50,   81,   88,   81,   65,   72,   88,
      132,  235,  235,   52,   52,   52,   52,   81,  502,   53,
       53,   53,   53,   72,   72,   53,  165,    8,   53,    8,
        8,    8,    8,   21,  167,   21,  167,  165,   21,  167,
       53,   21,   21,   93,   21,   21,   21,   21,   21,   93,
       21,  500,   21,  122,  499,  122,   21,   21,   62,  154,
       62,   62,   21,   21,   62,  128,  122,   62,   21,   21,
      128,  128,   21,  129,  498,   93,   93,  163,  209,  163,
      129,  166,  497,  166,  129,  168,  496,  134,  209,  172,
      163,  154,  154,  134,  166,  183,  214,  183,  183,   53,

       53,   53,   53,  490,  183,  172,  215,  214,  252,  252,
       21,  199,   21,   21,   21,   21,   22,  215,   22,  134,
      134,   22,  489,  199,   22,   22,  488,   22,   22,   22,
       22,   22,  269,   22,  199,   22,  262,  262,  191,   22,
       22,  191,  487,  269,  486,   22,   22,  191,  191,  484,
      191,   22,   22,  191,  168,   22,  168,  168,  184,  168,
      172,  172,  172,  172,  485,  184,  184,  468,  184,  184,
      459,  190,  184,  184,  485,  190,  190,  205,  184,  190,
      217,  190,  217,  275,  275,  217,  205,  200,  458,  200,
      190,  190,  455,   22,  190,   22,   22,   22,   22,   33,

      200,  205,  205,  212,  216,  212,  216,   33,  272,  270,
      272,  234,  442,  272,  290,  290,  212,  216,  234,  234,
      270,  234,  234,  248,  441,  234,  234,  470,  470,  440,
      241,  234,  439,  313,  241,  241,  472,  472,  241,   33,
      241,  437,   33,   33,  313,   33,   33,   33,   33,  241,
      241,  436,  312,  241,  312,  312,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,  433,   33,   33,
       33,  432,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,  112,  431,  112,  112,  267,  271,  267,  271,
      430,  112,  248,  429,  248,  248,  428,  248,  427,  267,

      271,  112,  258,  426,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  349,  112,  385,  425,  112,  112,  424,  112,
      112,  112,  112,  349,  398,  385,  398,  398,  423,  398,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  412,  112,  112,  112,  422,  112,  112,  112,  112,
      421,  112,  112,  112,  112,  112,  117,  420,  117,  117,
      418,  258,  415,  258,  258,  117,  258,  416,  413,  416,
      416,  474,  474,  412,  412,  117,  476,  476,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,  117,  117,

      117,  117,  117,  117,  117,  117,  411,  117,  478,  478,
      117,  117,  407,  117,  117,  117,  117,  445,  405,  445,
      445,  394,  445,  393,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  388,  117,  117,  117,  387,
      117,  117,  117,  117,  386,  117,  117,  117,  117,  117,
      186,  186,  380,  186,  186,  186,  186,  186,  186,  186,
      186,  186,  186,  186,  377,  186,  186,  237,  237,  376,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  289,  237,  237,  334,  375,  334,  334,  289,  289,
      374,  289,  289,  334,  373,  289,  289,  480,  480,  482,

      482,  289,  292,  292,  368,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  296,  292,  292,  365,
      296,  296,  364,  305,  296,  363,  296,  362,  361,  359,
      305,  305,  358,  305,  305,  296,  296,  305,  305,  296,
      352,  351,  350,  305,  307,  307,  347,  307,  307,  307,
      307,  307,  307,  307,  307,  307,  307,  307,  311,  307,
      307,  346,  311,  311,  417,  334,  311,  334,  311,  322,
      322,  322,  322,  345,  344,  322,  331,  311,  311,  329,
      342,  311,  333,  333,  333,  333,  325,  323,  333,  342,
      322,  333,  320,  319,  400,  400,  318,  400,  400,  317,

      316,  400,  400,  333,  342,  342,  335,  400,  335,  335,
      403,  403,  403,  403,  315,  335,  403,  336,  435,  336,
      336,  337,  314,  337,  337,  299,  336,  435,  298,  297,
      337,  403,  285,  417,  284,  417,  417,  417,  417,  283,
      282,  281,  435,  435,  280,  279,  277,  276,  268,  322,
      322,  322,  322,  330,  266,  338,  330,  338,  338,  263,
      450,  259,  450,  450,  338,  450,  330,  256,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  335,  330,  335,
      253,  330,  330,  249,  330,  330,  330,  330,  336,  245,

      336,  244,  337,  243,  337,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  242,  330,  330,  330,
      230,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  339,  229,  339,  339,  228,  338,  227,  338,  340,
      339,  340,  340,  226,  225,  402,  224,  222,  340,  402,
      402,  221,  213,  402,  211,  402,  208,  207,  206,  447,
      447,  203,  447,  447,  402,  402,  447,  447,  402,  449,
      202,  201,  447,  449,  449,  197,  194,  449,  192,  449,
      180,  175,  171,  452,  452,  477,  452,  452,  449,  449,
      452,  452,  449,  477,  169,  162,  452,  160,  454,  157,

      155,  153,  454,  454,  477,  477,  454,  149,  454,  147,
      145,  143,  339,  141,  339,  140,  139,  454,  454,  137,
      340,  454,  340,  366,  135,  366,  366,  461,  461,  133,
      461,  461,  131,  127,  461,  461,  124,  123,  116,  113,
      461,  105,  366,  103,  101,  366,  366,  366,  366,  366,
      366,  366,  366,  366,  366,  366,  366,  366,  366,  366,
      366,  366,  366,  100,  366,   99,   97,  366,  366,   96,
      366,  366,  366,  366,  492,   94,  492,  492,  492,  492,
       92,  366,  366,  366,  366,  366,  366,  366,  366,  366,
      366,  366,   90,  366,  366,  366,   86,  366,  366,  366,

      366,   83,  366,  366,  366,  366,  366,  378,   82,  378,
      378,   76,   74,   73,   70,   69,   66,   58,   56,   54,
       45,   43,   35,   18,   17,   16,  378,   15,    0,  378,
      378,  378,  378,  378,  378,  378,  378,  378,  378,  378,
      378,  378,  378,  378,  378,  378,  378,    0,  378,    0,
        0,  378,  378,    0,  378,  378,  378,  378,    0,    0,
        0,    0,    0,    0,    0,  378,  378,  378,  378,  378,
      378,  378,  378,  378,  378,  378,    0,  378,  378,  378,
        0,  378,  378,  378,  378,    0,  378,  378,  378,  378,
      378,  401,  401,    0,    0,  401,  401,  401,  401,  401,

      401,  401,  401,  401,  401,    0,  401,  401,  448,  448,
        0,    0,  448,  448,  448,  448,  448,  448,  448,  448,
      448,  448,    0,  448,  448,  453,  453,    0,    0,  453,
      453,  453,  453,  453,  453,  453,  453,  453,  453,    0,
      453,  453,  463,  463,    0,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  467,  463,  463,    0,
      467,  467,    0,    0,  467,  471,  467,    0,  469,  469,
      469,  469,  473,  471,  469,  467,  467,  469,  475,  467,
      473,    0,    0,    0,  471,  471,  475,    0,  471,  469,
        0,  473,  473,    0,  479,  473,  481,  475,  475,    0,

        0,  475,  479,  483,  481,    0,    0,    0,    0,    0,
        0,  483,    0,  479,  479,  481,  481,  479,    0,  481,
        0,    0,  483,  483,    0,    0,  483,  510,  510,  510,
      510,  510,  510,  510,  510,  510,  510,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  512,  512,  512,
      512,  512,  512,  512,  512,  512,  512,  513,  513,  513,
      513,  513,  513,  513,  513,  513,  513,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  515,  515,  515,
      515,  515,  515,  515,  515,  515,  515,  516,  516,  516,
      516,  516,  516,  516,  516,  516,  516,  517,  517,  517,

      517,  517,  517,  517,  517,  517,  517,  518,  518,  518,
      518,  518,  518,  518,  518,  518,  518,  519,  519,  519,
      519,  519,  519,  519,  519,  519,  519,  520,  520,  520,
      520,  520,  520,  520,  520,  520,  520,  521,  521,  521,
      521,  521,  521,  521,  521,  521,  521,  522,  522,  522,
      522,  522,  522,  522,  522,  522,  522,  523,  523,  523,
      523,  523,  523,  523,  523,  523,  523,  524,  524,  524,
      524,  524,  524,  524,  524,  524,  524,  525,  525,    0,
        0,    0,    0,    0,    0,  525,  526,  526,  526,  526,
      526,  527,  527,  527,  527,  527,  528,  528,    0,    0,

      528,  529,  529,  529,  529,  529,  529,  529,  529,  529,
      529,  530,  530,  530,  530,  530,  531,  531,  531,  531,
      531,  532,  532,    0,    0,  532,  533,  533,  533,  533,
      533,  534,  534,  534,  534,  534,  535,  535,    0,    0,
      535,  536,  536,  536,  536,  536,  537,  537,  537,  537,
      537,  538,  538,    0,    0,  538,  539,  539,  539,  539,
      539,  540,  540,  540,  540,  540,  541,  541,  542,  542,
      542,  542,  542,  543,  543,  543,  543,  543,  545,  545,
      545,  545,  545,  546,  546,  546,  546,  546,  547,  547,
      549,  549,  549,  549,  549,  550,  550,  550,  550,  550,

      551,  551,  552,  552,  552,  552,  552,  553,  553,  553,
      553,  553,  554,  554,  554,  554,  554,  555,  555,  555,
      555,    0,    0,  555,  555,  556,  556,  556,  556,  556,
      557,  557,  557,  557,  557,  559,  559,  559,  559,  559,
      560,  560,  560,  560,  560,  561,  561,    0,    0,  561,
      562,  562,  562,  562,  562,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lex.l"
#line 2 "lex.l"
#include "main.h"
#include "yacc.tab.h"

#undef YY_INPUT
#define YY_INPUT(buf,result,max_size) { \
	int c = fgetc(yyin); \
	result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
	myoffset++;\
	}

extern "C" {
	int yywrap(void);
	int yylex(void);
	ostream& warn(int cur = 0);
	ostream& info(int cur = 0);
	ostream& error(int cur = 0);
	int myoffset;
}

#line 1050 "lex.yy.c"

#line 1052 "lex.yy.c"

#define INITIAL 0
#define TXT1 1
#define TXT1P 2
#define EQU1 3
#define EQU1T 4
#define EQU1JJV 5
#define EQU1JJC 6
#define TXTS1 7
#define TXTS2 8
#define TXTS 9
#define EQUS 10
#define EQUST 11
#define EQUSJJV 12
#define EQUSJJC 13
#define JJV 14
#define JJC 15
#define ITAL 16

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 71 "lex.l"


#line 1291 "lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 510 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1756 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 73 "lex.l"
{
	//cout << "【首】" << yytext;
}
	YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 77 "lex.l"
{
	//cout << "【题】" << yytext << endl;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 81 "lex.l"
{
	warn() << "下列标点不应该连用`" << yytext << "`。" << endl;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 85 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 89 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 93 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 97 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 101 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 105 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 109 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 113 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 117 "lex.l"
{
	info() << "下列标点连用前请认真检查语气是否足够强烈`" << yytext << "`。" << endl;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 121 "lex.l"
{
	warn() << "下列中文或标点之间不应该插入空白符。" << endl;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 125 "lex.l"
{
	warn() << "下列外文和标点之间不应该插入空白符。" << endl;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 129 "lex.l"
{
	warn() << "下列标点和外文之间不应该插入空白符。" << endl;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 133 "lex.l"
{
	warn() << "下列中文和外文之间应当插入空格。" << endl;
}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 137 "lex.l"
{
	warn(-1) << "段末应当有标点符号。" << endl;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 141 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 145 "lex.l"
{
	//cout << "【标】" << yytext;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 149 "lex.l"
{
	//cout << "【词】" << yytext;
	if(yyleng == 1 && (('b' <= yytext[0] && yytext[0] <= 'z') || ('K' <= yytext[0] && yytext[0] <= 'N')))
		info() << "字符`" << yytext << "`可能是一个变量，是的话请放在公式中。" << endl;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 155 "lex.l"
{
	warn() << "数`" << yytext << "`比较长，考虑放入公式中并使用变量保存。" << endl;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 159 "lex.l"
{
	if(yyleng >= 6)
		warn() << "数`" << yytext << "`比较长，考虑放入公式中并使用变量保存。" << endl;
	//cout << "【数】" << yytext;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 165 "lex.l"
{
	warn() << "一般不应该出现英文标点`" << yytext << "`。" << endl;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 169 "lex.l"
{
	warn() << "非行首一般不应该出现制表符。" << endl;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 173 "lex.l"
{
	//cout << "【符】" << yytext;
}
	YY_BREAK
case 26:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 177 "lex.l"
{
	//cout << "【↓块1】" << yytext + 3;
	BEGIN TXT1;
}
	YY_BREAK
case 27:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 182 "lex.l"
{
	//cout << "【↑块1】" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 187 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 191 "lex.l"
{
	warn() << "文字和字符串之间应当插入空格。" << endl;
	BEGIN TXTS;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 196 "lex.l"
{
	warn() << "标点和字符串之间不应当插入空格。" << endl;
	BEGIN TXTS;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 201 "lex.l"
{
	//cout << "【<s】";
	BEGIN TXTS1;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 206 "lex.l"
{
	BEGIN TXTS2;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 210 "lex.l"
{
	//cout << "【↓块1】";
	BEGIN TXT1P;
}
	YY_BREAK
case 34:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 215 "lex.l"
{
	//cout << "lang = " << yytext << endl;
	BEGIN TXT1;
}
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 220 "lex.l"
{
	error() << "不允许出现连续两个反引号`。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 225 "lex.l"
{
	//cout << "【<s】" << yytext;
	BEGIN TXTS;
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 230 "lex.l"
{
	warn() << "字符串和文字之间应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 235 "lex.l"
{
	warn() << "字符串和标点之间不应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 240 "lex.l"
{
	//cout << "【s>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 245 "lex.l"
{
	error() << "行内字符串不能包含换行。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 250 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 42:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 254 "lex.l"
{
	//cout << "【↓式1】" << endl;
	BEGIN EQU1;
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 259 "lex.l"
{
	error() << "行内公式只使用一个`$`。" << endl;
	BEGIN EQU1;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 264 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\" << yytext << "`。" << endl;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 268 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\" << yytext << "`。" << endl;
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 272 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\le`。" << endl;
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 276 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\le`。" << endl;
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 280 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\ge`。" << endl;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 284 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\ge`。" << endl;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 288 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\dots`（对于分隔逗号等符号）或`\\cdots`（对于分隔加号、小于号等符号）等。" << endl;
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 292 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\dots`（对于分隔逗号等符号）或`\\cdots`（对于分隔加号、小于号等符号）等。" << endl;
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 296 "lex.l"
{
	info() << "在公式中`mod`一般写成`\\bmod`或`\\pmod`。" << endl;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 300 "lex.l"
{
	info() << "在公式中`mod`一般写成`\\bmod`或`\\pmod`。" << endl;
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 304 "lex.l"
{
	info() << "在公式中一般不用星号`*`做乘号，而用叉乘`\\times`、点乘`\\cdot`或省略。" << endl;
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 308 "lex.l"
{
	info() << "在公式中一般不用星号`*`做乘号，而用叉乘`\\times`、点乘`\\cdot`或省略。" << endl;
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 312 "lex.l"
{
	info() << "在公式中一般不用斜杠`/`做除号，而用除号`\\div`或分数`\\frac{1}{2}`。" << endl;
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 316 "lex.l"
{
	info() << "在公式中一般不用斜杠`/`做除号，而用除号`\\div`或分数`\\frac{1}{2}`。" << endl;
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 320 "lex.l"
{
	if(yyleng >= 6)
		warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 325 "lex.l"
{
	if(yyleng >= 6)
		warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 330 "lex.l"
{
	warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 334 "lex.l"
{
	warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 338 "lex.l"
{
	error() << "公式中不能存在汉字和中文标点。" << endl;
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 342 "lex.l"
{
	error() << "公式中不能存在汉字和中文标点。" << endl;
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 346 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1T;
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 351 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1;
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 356 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1;
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 361 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1;
}
	YY_BREAK
case 68:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 366 "lex.l"
{
	//cout << "【↑式1】" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 371 "lex.l"
{
	error() << "行内公式只使用一个`$`。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 376 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 380 "lex.l"
{
	error() << "行内公式前$后不能加空格。" << endl;
	BEGIN EQUS;
}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 385 "lex.l"
{
	warn() << "文字和公式之间应当插入空格。" << endl;
	BEGIN EQUS;
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 390 "lex.l"
{
	warn() << "标点和公式之间不应当插入空格。" << endl;
	BEGIN EQUS;
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 395 "lex.l"
{
	//cout << "【<e】";
	BEGIN EQUS;
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 400 "lex.l"
{
	//cout << yytext;
	BEGIN EQUST;
}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 405 "lex.l"
{
	//cout << yytext;
	BEGIN EQUS;
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 410 "lex.l"
{
	//cout << yytext;
	BEGIN EQUS;
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 415 "lex.l"
{
	//cout << yytext;
	BEGIN EQUS;
}
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 420 "lex.l"
{
	error() << "行内公式不能换行。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 425 "lex.l"
{
	error() << "行内公式后$前不能加空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 430 "lex.l"
{
	warn() << "公式和文字之间应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 435 "lex.l"
{
	warn() << "公式和标点之间不应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 440 "lex.l"
{
	//cout << "【e>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 445 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 449 "lex.l"
{
	//cout << "【<v】";
	BEGIN JJV;
}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 454 "lex.l"
{
	//cout << "【v>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 459 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 463 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQUSJJV;
}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 468 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQUS;
}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 473 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 477 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQU1JJV;
}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 482 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQU1;
}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 487 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 491 "lex.l"
{
	//cout << "【<c】";
	BEGIN JJV;
}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 496 "lex.l"
{
	//cout << "【c>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 501 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 505 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQUSJJC;
}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 510 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQUS;
}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 515 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 519 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQU1JJC;
}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 524 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQU1;
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 529 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 533 "lex.l"
{
	//cout << "【空】";
}
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 537 "lex.l"
{
	//cout << "【换】" << endl;
}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 541 "lex.l"
{
	//cout << "【粗】"
}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 545 "lex.l"
{
	//cout << "【斜】"
	BEGIN ITAL;
}
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 550 "lex.l"
{
	error() << "斜体中不能换行。" << endl;
}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 554 "lex.l"
{
	warn() << "斜体一般只用于表示文件名，强调请用加粗。" << endl;
}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 558 "lex.l"
{
	//cout << "【斜】";
	BEGIN INITIAL;
}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 563 "lex.l"
{
	//cout << "【??】" << yytext;
}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 567 "lex.l"
ECHO;
	YY_BREAK
#line 2203 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(TXT1):
case YY_STATE_EOF(TXT1P):
case YY_STATE_EOF(EQU1):
case YY_STATE_EOF(EQU1T):
case YY_STATE_EOF(EQU1JJV):
case YY_STATE_EOF(EQU1JJC):
case YY_STATE_EOF(TXTS1):
case YY_STATE_EOF(TXTS2):
case YY_STATE_EOF(TXTS):
case YY_STATE_EOF(EQUS):
case YY_STATE_EOF(EQUST):
case YY_STATE_EOF(EQUSJJV):
case YY_STATE_EOF(EQUSJJC):
case YY_STATE_EOF(JJV):
case YY_STATE_EOF(JJC):
case YY_STATE_EOF(ITAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 510 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 510 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 509);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 567 "lex.l"


int yywrap(void)
{
	return 1;
}

ostream& error(int cur){
	return cerr << "E " << myoffset + cur << " ";
}

ostream& warn(int cur){
	return cerr << "W " << myoffset + cur << " ";
}

ostream& info(int cur){
	return cerr << "I " << myoffset + cur << " ";
}

